Choice class

Provides a random choice from items in a sequence.

Constructors

Choice({int? seed})
Provides a random choice from items in a sequence.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
final

Methods

choose<T>({required List<T> items, int length = 1, bool unique = false}) List<T>
Returns a randomly-chosen list of elements from provided items.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited