CountrySpecific class

Provides special data related to specific country.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

brazil({int? seed}) → Brazil
Provides special data for Brazil.
denmark({int? seed}) → Denmark
Provides special data for Denmark.
italy({int? seed}) → Italy
Provides special data for Italy.
netherlands({int? seed}) → Netherlands
Provides special data for Netherlands.
poland({int? seed}) → Poland
Provides special data for Poland.
russia({int? seed}) → Russia
Provides special data for Russia.
ukraine({int? seed}) → Ukraine
Provides special data for Ukraine.
usa({int? seed}) → USA
Provides special data for USA.