DSNType enum
DSN types.
Values
- postgres → const DSNType
-
const DSNType(scheme: 'postgres', port: 5432) - mysql → const DSNType
-
const DSNType(scheme: 'mysql', port: 3306) - mongodb → const DSNType
-
const DSNType(scheme: 'mongodb', port: 27017) - redis → const DSNType
-
const DSNType(scheme: 'redis', port: 6379) - couchbase → const DSNType
-
const DSNType(scheme: 'couchbase', port: 8092) - memcached → const DSNType
-
const DSNType(scheme: 'memcached', port: 11211) - rabbitmq → const DSNType
-
const DSNType(scheme: 'rabbitmq', port: 5672)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - port → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited