Food class

Provides data related to food.

Constructors

Food({Locale locale = Locale.en, int? seed})
Provides data related to food.
const

Properties

dish String
Returns a random dish name.
no setter
drink String
Returns a random drink name.
no setter
fruit String
Returns a random fruit or berry name.
no setter
hashCode int
The hash code for this object.
no setterinherited
locale Locale
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
final
spice String
Returns a random spice/herb name.
no setter
vegetable String
Returns a random vegetable name.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited