Hardware class

Provides data related to hardware.

Constructors

Hardware({int? seed})
Provides data related to hardware.
const

Properties

cpu String
Returns a random CPU name.
no setter
cpuCodeName String
Returns a random CPU code name.
no setter
cpuFrequency String
Returns a random frequency of CPU.
no setter
generation String
Returns a random generation.
no setter
graphics String
Returns a random graphics.
no setter
hashCode int
The hash code for this object.
no setterinherited
manufacturer String
Returns a random manufacturer.
no setter
phoneModel String
Returns a random phone model.
no setter
ramSize String
Returns a random RAM size.
no setter
ramType String
Returns a random RAM type.
no setter
resolution String
Returns a random screen resolution.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenSize String
Returns a random size of screen in inches.
no setter
seed int?
final
ssdOrHdd String
Returns a random type of disk.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited