MeasureUnit enum
Measure unit names and symbols.
Values
- mass → const MeasureUnit
-
const MeasureUnit(name: 'gram', symbol: 'gr') - information → const MeasureUnit
-
const MeasureUnit(name: 'byte', symbol: 'b') - thermodynamicTemperature → const MeasureUnit
-
const MeasureUnit(name: 'kelvin', symbol: 'K') - amountOfSubstance → const MeasureUnit
-
const MeasureUnit(name: 'mole', symbol: 'mol') - angle → const MeasureUnit
-
const MeasureUnit(name: 'radian', symbol: 'r') - solidAngle → const MeasureUnit
-
const MeasureUnit(name: 'steradian', symbol: 'sr') - frequency → const MeasureUnit
-
const MeasureUnit(name: 'hertz', symbol: 'Hz') - force → const MeasureUnit
-
const MeasureUnit(name: 'newton', symbol: 'N') - pressure → const MeasureUnit
-
const MeasureUnit(name: 'pascal', symbol: 'P') - energy → const MeasureUnit
-
const MeasureUnit(name: 'joule', symbol: 'J') - power → const MeasureUnit
-
const MeasureUnit(name: 'watt', symbol: 'W') - flux → const MeasureUnit
-
const MeasureUnit(name: 'watt', symbol: 'W') - electricCharge → const MeasureUnit
-
const MeasureUnit(name: 'coulomb', symbol: 'C') - voltage → const MeasureUnit
-
const MeasureUnit(name: 'volt', symbol: 'V') - electricCapacitance → const MeasureUnit
-
const MeasureUnit(name: 'farad', symbol: 'F') - electricResistance → const MeasureUnit
-
const MeasureUnit(name: 'ohm', symbol: 'Ω') - electricalConductance → const MeasureUnit
-
const MeasureUnit(name: 'siemens', symbol: 'S') - magneticFlux → const MeasureUnit
-
const MeasureUnit(name: 'weber', symbol: 'Wb') - magneticFluxDensity → const MeasureUnit
-
const MeasureUnit(name: 'tesla', symbol: 'T') - inductance → const MeasureUnit
-
const MeasureUnit(name: 'henry', symbol: 'H') - temperature → const MeasureUnit
-
const MeasureUnit(name: 'celcius', symbol: '°C') - radioactivity → const MeasureUnit
-
const MeasureUnit(name: 'becquerel', symbol: 'Bq')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MeasureUnit> - A constant List of the values in this enum, in order of their declaration.