Numeric class

Provider of data related to generating numeric data.

Constructors

Numeric({int? seed})
Provider of data related to generating numeric data.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
final

Methods

complexes({double realStart = 0.0, double realEnd = 1.0, int realPrecision = 15, double imaginaryStart = 0.0, double imaginaryEnd = 1.0, int imaginaryPrecision = 15, int n = 10}) List<({double imaginary, double real})>
Returns a list of random complex numbers.
complexNumber({double realStart = 0.0, double realEnd = 1.0, int realPrecision = 15, double imaginaryStart = 0.0, double imaginaryEnd = 1.0, int imaginaryPrecision = 15}) → ({double imaginary, double real})
Returns a random complex number.
floatNumber({double start = -1000.0, double end = 1000.0, int precision = 15}) double
Returns a random float number in range `start`, `end` (inclusive).
floats({double start = 0.0, double end = 1.0, int n = 10, int precision = 15}) List<double>
Returns a list of random float numbers.
integerNumber({int start = -1000, int end = 1000}) int
Returns a random integer in range [start, end] (inclusive).
integers({int start = 0, int end = 10, int n = 10}) List<int>
Returns a list of random integers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited