Path class

Provides data related to paths.

Constructors

Path({String? platform, int? seed})
Provides data related to paths.

Properties

devDir String
Returns a random path to development directory.
no setter
hashCode int
The hash code for this object.
no setterinherited
home String
Returns a home path.
no setter
platform String
final
projectDir String
Returns a random path to project directory.
no setter
root String
Returns a root dir path.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
final
user String
Returns a path to random user.
no setter
usersFolder String
Returns a random path to user's folders.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited