Payment class

Provides data related to payment.

Constructors

Payment({int? seed})
Provides data related to payment.
const

Properties

bitcoinAddress String
Returns a random bitcoin address.
no setter
cid String
Returns a random CID code.
no setter
creditCardNetwork String
Returns a random credit card network.
no setter
cvv String
Returns a random CVV code.
no setter
ethereumAddress String
Returns a random Ethereum address.
no setter
hashCode int
The hash code for this object.
no setterinherited
paypal String
Returns a random email of PayPal account.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
final

Methods

creditCardExpirationDate({int min = 18, int max = 25}) String
Returns a random expiration date for credit card.
creditCardNumber({CardType cardType = .visa}) String
Returns a random credit card number.
creditCardOwner({Gender? gender}) → ({String card, String expirationDate, String owner})
Returns credit card owner.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited