Person class

Provides personal data.

Constructors

Person({Locale locale = Locale.en, int? seed})
Provides personal data.
const

Properties

academicDegree String
Returns a random academic degree.
no setter
bloodType String
Returns a random blood type (blood group).
no setter
gender String
Returns a random gender title.
no setter
genderCode int
Returns a random ISO/IEC 5218 gender code.
no setter
genderSymbol String
Returns a random sex symbol.
no setter
hashCode int
The hash code for this object.
no setterinherited
language String
Returns a random language name.
no setter
locale Locale
final
occupation String
Returns a random occupation (job).
no setter
politicalViews String
Returns a random political views.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
final
university String
Returns a random university name.
no setter
viewsOn String
Returns a random views on something.
no setter
worldview String
Returns a random worldview.
no setter

Methods

birthdate({int minYear = 1980, int? maxYear}) String
Returns a random birthdate in the YYYY-MM-DD format.
email({List<String>? domains, bool unique = false}) String
Returns a random email.
fullName({Gender? gender, bool reverse = false}) String
Returns a random full name.
height({double min = 1.5, double max = 2.0}) String
Returns a random height in meters.
identifier({String mask = "##-##/##"}) String
Returns a random identifier by mask.
name({Gender? gender}) String
Returns a random name.
nationality({Gender? gender}) String
Returns a random nationality.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
password({int length = 8, bool isHashed = false}) String
Returns a random password or SHA256 hash of password.
patronymic({Gender? gender}) String
Returns a random patronymic name. Specific to Locale.ru and Locale.uk.
phoneNumber({String? mask, bool asE164 = false}) String
Returns a random phone number.
surname({Gender? gender}) String
Returns a random surname.
title({Gender? gender, TitleType? titleType}) String
Returns a random title for name.
toString() String
A string representation of this object.
inherited
username({String mask = 'l_d', int digitsMin = 1800, int digitsMax = 2100}) String
Returns username from template.
weight({int min = 38, int max = 90}) int
Returns a random weight in kilograms.

Operators

operator ==(Object other) bool
The equality operator.
inherited