PostalService enum

Inheritance
Available extensions

Values

usps → const PostalService
const PostalService(name: 'USPS', masks: ["#### #### #### #### ####", "@@ ### ### ### US"])
fedex → const PostalService
const PostalService(name: 'FedEx', masks: ["#### #### ####", "#### #### #### ###"])
ups → const PostalService
const PostalService(name: 'UPS', masks: ["1Z@####@##########"])

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
masks List<String>
final
name String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PostalService>
A constant List of the values in this enum, in order of their declaration.