Science class

Provides data related to science.

Constructors

Science({int? seed})
Provides data related to food.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
final

Methods

dnaSequence({int lenght = 10}) String
Returns a random DNA sequence.
measureUnit({MeasureUnit? name, bool asSymbol = false}) String
Returns unit name from the International System of Units.
metricPrefix({MetricPrefixSign? sign, bool asSymbol = false}) String
Returns a random prefix for the International System of Units.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited