Address class
Provides data related to geographical location.
Constructors
Properties
- address → String
-
Returns a random full address.
no setter
- callingCode → String
-
Returns a random calling code of random country.
no setter
- city → String
-
Returns a random city.
no setter
- country → String
-
Returns a random country.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iataCode → String
-
Returns a random a random IATA code.
no setter
- icaoCode → String
-
Returns a random a random ICAO code.
no setter
- locale → Locale
-
final
- postalCode → String
-
Returns a postal code for provided locale.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryAddress → String
-
Returns a random secondary address.
no setter
- seed → int?
-
final
- streetName → String
-
Returns a random street name.
no setter
- streetSuffix → String
-
Returns a random street suffix if locale has any.
no setter
Methods
-
continent(
{bool asCode = false}) → String - Returns a random continent name or continent code.
-
coordinates(
{bool asDMS = false}) → ({String latitude, String longitude}) - Returns a random geo coordinates.
-
countryCode(
{CountryCode code = .a2}) → String - Returns a random code of country.
-
latitude(
{bool asDMS = false}) → String - Returns a random value of latitude.
-
longitude(
{bool asDMS = false}) → String - Returns a random value of longitude.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
state(
{bool isAbbr = false}) → String - Returns a random administrative district of the country.
-
streetNumber(
{int max = 1400}) → int - Returns a random street number.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited