Choice class
Provides a random choice from items in a sequence.
Properties
Methods
-
choose<
T> ({required List< T> items, int length = 1, bool unique = false}) → List<T> -
Returns a randomly-chosen list of elements from provided
items. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited