Code class
Provides data related to codes.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- imei → String
-
Returns a random IMEI.
no setter
- localeCode → String
-
Returns a random locale code (MS-LCID).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → int?
-
final
Methods
-
ean(
{EANFormat? format}) → String - Returns EAN.
-
isbn(
{ISBNFormat? format, Locale? locale}) → String - Returns ISBN.
-
issn(
{String mask = "####-####"}) → String - Returns a random ISSN.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pin(
{String mask = "####"}) → String - Returns a random PIN code.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited