IPv4Purpose enum
IPv4 address ranges for different purposes.
Values
- thisNetwork → const IPv4Purpose
-
const IPv4Purpose(min: 0, max: 16777215) - amt → const IPv4Purpose
-
const IPv4Purpose(min: 3224682752, max: 3224683007) - loopback → const IPv4Purpose
-
const IPv4Purpose(min: 2130706432, max: 2147483647) - as112v4 → const IPv4Purpose
-
const IPv4Purpose(min: 3223307264, max: 3223307519) - linkLocal → const IPv4Purpose
-
const IPv4Purpose(min: 2851995648, max: 2852061183) - testNet1 → const IPv4Purpose
-
const IPv4Purpose(min: 3221225984, max: 3221226239) - testNet2 → const IPv4Purpose
-
const IPv4Purpose(min: 3325256704, max: 3325256959) - testNet3 → const IPv4Purpose
-
const IPv4Purpose(min: 3405803776, max: 3405804031) - benchmarking → const IPv4Purpose
-
const IPv4Purpose(min: 3323068416, max: 3323199487) - privateUse1 → const IPv4Purpose
-
const IPv4Purpose(min: 167772160, max: 184549375) - privateUse2 → const IPv4Purpose
-
const IPv4Purpose(min: 2886729728, max: 2887778303) - privateUse3 → const IPv4Purpose
-
const IPv4Purpose(min: 3232235520, max: 3232301055) - reserved → const IPv4Purpose
-
const IPv4Purpose(min: 4026531840, max: 4294967295) -
const IPv4Purpose(min: 1681915904, max: 1686110207) - limitedBroadcast → const IPv4Purpose
-
const IPv4Purpose(min: 4294967295, max: 4294967295) - ipv4DummyAddress → const IPv4Purpose
-
const IPv4Purpose(min: 3221225480, max: 3221225480) - turnRelayAnycast → const IPv4Purpose
-
const IPv4Purpose(min: 3221225482, max: 3221225482) - ietfProtocolAssignments → const IPv4Purpose
-
const IPv4Purpose(min: 3221225472, max: 3221225727) - portControlProtocolAnycast → const IPv4Purpose
-
const IPv4Purpose(min: 3221225481, max: 3221225481) - ipv4ServiceContinuityPrefix → const IPv4Purpose
-
const IPv4Purpose(min: 3221225472, max: 3221225479) - directDelegationAs112Service → const IPv4Purpose
-
const IPv4Purpose(min: 3232706560, max: 3232706815)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- max → int
-
final
- min → int
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IPv4Purpose> - A constant List of the values in this enum, in order of their declaration.