Internet class
Provides data related to internet.
Properties
- asn → String
-
Returns a random ASN (Autonomous System Number).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod → String
-
Returns a random HTTP method.
no setter
- httpStatusCode → int
-
Returns a random HTTP status code.
no setter
- httpStatusMessage → String
-
Returns a random HTTP status message.
no setter
- ipv6 → String
-
Returns a random IPv6 address.
no setter
- ipv6CIDR → String
-
Returns a random IPv6 CIDR address.
no setter
- macAddress → String
-
Returns a random MAC address.
no setter
- publicDNS → String
-
Returns a random public DNS.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → int?
-
final
- userAgent → String
-
Returns a random user agent.
no setter
Methods
-
cloudRegion(
{String? separator = '-'}) → String - Returns a random cloud provider region identifier.
-
contentType(
{MimeType? mimeType}) → String - Returns a random HTTP content type.
-
dsn(
{DSNType? dsnType, TLDType? tldType, List< String> ? subdomains}) → String - Returns a random DSN (Data Source Name).
-
hostname(
{TLDType? tldType, List< String> ? subdomains}) → String - Returns a random hostname without scheme.
-
ipv4(
{IPv4Purpose? purpose, PortRange? portRange}) → String - Returns a random IPv4 address.
-
ipv4CIDR(
{IPv4Purpose? purpose}) → String - Returns a random IPv4 CIDR address.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
path(
{int? parts}) → String -
Returns a random path of given
partscount. -
port(
{PortRange range = PortRange.all}) → int - Returns random port.
-
queryParameters(
{int? count}) → Map< String, String> - Returns arbitrary query parameters.
-
queryString(
{int? count}) → String - Returns arbitrary query string.
-
slug(
{int? parts}) → String -
Returns a random slug of given
partscount. -
topLevelDomain(
{TLDType type = TLDType.cctld}) → String - Returns random top level domain.
-
toString(
) → String -
A string representation of this object.
inherited
-
uri(
{URLScheme urlScheme = URLScheme.https, TLDType? tldType, List< String> ? subdomains, int? queryParameters}) → String - Returns a random URI.
-
url(
{URLScheme urlScheme = URLScheme.https, PortRange? portRange, TLDType? tldType, List< String> ? subdomains}) → String - Returns random URL.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited