Locale enum
Values
- az → const Locale
- ar_ae → const Locale
- ar_dz → const Locale
- ar_eg → const Locale
- ar_jo → const Locale
- ar_kw → const Locale
- ar_ma → const Locale
- ar_om → const Locale
- ar_qa → const Locale
- ar_sa → const Locale
- ar_sy → const Locale
- ar_tn → const Locale
- ar_ye → const Locale
- da → const Locale
- cs → const Locale
- de_at → const Locale
- de_ch → const Locale
- de → const Locale
- el → const Locale
- en_au → const Locale
- en_ca → const Locale
- en_gb → const Locale
- en → const Locale
- es_mx → const Locale
- es → const Locale
- et → const Locale
- fa → const Locale
- fi → const Locale
- fr → const Locale
- hr → const Locale
- hu → const Locale
- isl → const Locale
- it → const Locale
- ja → const Locale
- kk → const Locale
- ko → const Locale
- nl_be → const Locale
- nl → const Locale
- no → const Locale
- pl → const Locale
- pt_br → const Locale
- pt → const Locale
- ru → const Locale
- sk → const Locale
- sv → const Locale
- tr → const Locale
- uk → const Locale
- zh → const Locale
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited