Science class
Provides data related to science.
Properties
Methods
-
dnaSequence(
{int lenght = 10}) → String - Returns a random DNA sequence.
-
measureUnit(
{MeasureUnit? name, bool asSymbol = false}) → String - Returns unit name from the International System of Units.
-
metricPrefix(
{MetricPrefixSign? sign, bool asSymbol = false}) → String - Returns a random prefix for the International System of Units.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited